Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.html4
-rw-r--r--doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.textile4
-rw-r--r--plugins/org.eclipse.eef.edit/plugin.properties5
-rw-r--r--plugins/org.eclipse.eef.edit/src-gen/org/eclipse/eef/provider/EEFDynamicMappingForItemProvider.java16
-rw-r--r--plugins/org.eclipse.eef.ide.ui/src/org/eclipse/eef/ide/ui/internal/widgets/EEFControlSwitch.java10
-rw-r--r--plugins/org.eclipse.eef/model/eef.ecore6
-rw-r--r--plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EEFDynamicMappingFor.java26
-rw-r--r--plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EefPackage.java26
-rw-r--r--plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EEFDynamicMappingForImpl.java50
-rw-r--r--plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EefPackageImpl.java8
10 files changed, 78 insertions, 77 deletions
diff --git a/doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.html b/doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.html
index c8e981a41..8e52ec517 100644
--- a/doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.html
+++ b/doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.html
@@ -13,10 +13,10 @@
</p>
<h3 id="properties">Properties</h3>
<ul>
- <li>domainClassExpression: This expression will use concepts of the meta-model in order to compute the number of element to take into account. This expression must return a collection of element on which we will iterate to create the widgets. For example, to fulfill our requirement of one text widget for each property with the type EString, you could type the following domainClassExpression
+ <li>iterableExpression: This expression will use concepts of the meta-model in order to compute the number of element to take into account. This expression must return a collection of elements on which we will iterate to create the widgets. For example, to fulfill our requirement of one text widget for each property with the type EString, you could type the following iterableExpression
<code>aql:self.eClass().eAllStructuralFeatures</code>.
</li>
- <li>iterator: The iterator will be used to define a name to manipulate the result of the domain class expression. To fulfill our requirement, we could use the name
+ <li>iterator: The iterator will be used to define a name to manipulate the result of the iterable expression. To fulfill our requirement, we could use the name
<code>eStructuralFeature</code>.
</li>
<li>ifs: This property will contain all the use cases that can be handled by our dynamic mapping.</li>
diff --git a/doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.textile b/doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.textile
index 928d39b8f..7b97eaf38 100644
--- a/doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.textile
+++ b/doc/org.eclipse.eef.documentation/pages/language/dynamicmappings.textile
@@ -6,8 +6,8 @@ The dynamic mapping is an advanced concept used to handle complex meta-model mor
h3(#properties). Properties
-* domainClassExpression: This expression will use concepts of the meta-model in order to compute the number of element to take into account. This expression must return a collection of element on which we will iterate to create the widgets. For example, to fulfill our requirement of one text widget for each property with the type EString, you could type the following domainClassExpression @aql:self.eClass().eAllStructuralFeatures@.
-* iterator: The iterator will be used to define a name to manipulate the result of the domain class expression. To fulfill our requirement, we could use the name @eStructuralFeature@.
+* iterableExpression: This expression will use concepts of the meta-model in order to compute the number of element to take into account. This expression must return a collection of elements on which we will iterate to create the widgets. For example, to fulfill our requirement of one text widget for each property with the type EString, you could type the following iterableExpression @aql:self.eClass().eAllStructuralFeatures@.
+* iterator: The iterator will be used to define a name to manipulate the result of the iterable expression. To fulfill our requirement, we could use the name @eStructuralFeature@.
* ifs: This property will contain all the use cases that can be handled by our dynamic mapping.
An "if" contains the following two properties:
diff --git a/plugins/org.eclipse.eef.edit/plugin.properties b/plugins/org.eclipse.eef.edit/plugin.properties
index 485319512..bc91a736b 100644
--- a/plugins/org.eclipse.eef.edit/plugin.properties
+++ b/plugins/org.eclipse.eef.edit/plugin.properties
@@ -114,7 +114,7 @@ _UI_EEFTextDescription_editExpression_feature = Edit Expression
_UI_EEFTextDescription_lineCount_feature = Line Count
_UI_EEFTextDescription_style_feature = Style
_UI_EEFTextDescription_conditionalStyles_feature = Conditional Styles
-_UI_EEFLabelDescription_bodyExpression_feature = Body Expression
+_UI_EEFLabelDescription_valueExpression_feature = Value Expression
_UI_EEFLabelDescription_style_feature = Style
_UI_EEFLabelDescription_conditionalStyles_feature = Conditional Styles
_UI_EEFButtonDescription_buttonLabelExpression_feature = Button Label Expression
@@ -143,7 +143,7 @@ _UI_EEFHyperlinkDescription_onClickExpression_feature = On Click Expression
_UI_EEFHyperlinkDescription_style_feature = Style
_UI_EEFHyperlinkDescription_conditionalStyles_feature = Conditional Styles
_UI_EEFDynamicMappingFor_iterator_feature = Iterator
-_UI_EEFDynamicMappingFor_domainClassExpression_feature = Domain Class Expression
+_UI_EEFDynamicMappingFor_iterableExpression_feature = Iterable Expression
_UI_EEFDynamicMappingFor_ifs_feature = Ifs
_UI_EEFDynamicMappingIf_predicateExpression_feature = Predicate Expression
_UI_EEFDynamicMappingIf_widget_feature = Widget
@@ -223,3 +223,4 @@ _UI_EEFGroupStyle_expandedByDefault_feature = Expanded By Default
_UI_EEFGroupConditionalStyle_type = EEF Group Conditional Style
_UI_EEFGroupConditionalStyle_style_feature = Style
_UI_EEFGroupDescription_conditionalStyles_feature = Conditional Styles
+
diff --git a/plugins/org.eclipse.eef.ide.ui/src/org/eclipse/eef/ide/ui/internal/widgets/EEFControlSwitch.java b/plugins/org.eclipse.eef.ide.ui/src/org/eclipse/eef/ide/ui/internal/widgets/EEFControlSwitch.java
index 4751489f7..e5daac2de 100644
--- a/plugins/org.eclipse.eef.ide.ui/src/org/eclipse/eef/ide/ui/internal/widgets/EEFControlSwitch.java
+++ b/plugins/org.eclipse.eef.ide.ui/src/org/eclipse/eef/ide/ui/internal/widgets/EEFControlSwitch.java
@@ -243,15 +243,15 @@ public class EEFControlSwitch {
EEFDynamicMappingFor dynamicMappingFor, IVariableManager variableManager) {
List<IEEFLifecycleManager> lifecycleManagers = new ArrayList<IEEFLifecycleManager>();
- String domainClassExpression = dynamicMappingFor.getDomainClassExpression();
- EAttribute domainClassEAttribute = EefPackage.Literals.EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION;
+ String iterableExpression = dynamicMappingFor.getIterableExpression();
+ EAttribute iterableEAttribute = EefPackage.Literals.EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION;
String iterator = dynamicMappingFor.getIterator();
EAttribute ifExpressionEAttribute = EefPackage.Literals.EEF_DYNAMIC_MAPPING_IF__PREDICATE_EXPRESSION;
- Object domainClassExpressionResult = EvalFactory.of(this.interpreter, variableManager).logIfBlank(domainClassEAttribute)
- .evaluate(domainClassExpression);
- for (Object object : Util.asIterable(domainClassExpressionResult, Object.class)) {
+ Object iterableExpressionResult = EvalFactory.of(this.interpreter, variableManager).logIfBlank(iterableEAttribute)
+ .evaluate(iterableExpression);
+ for (Object object : Util.asIterable(iterableExpressionResult, Object.class)) {
Map<String, Object> switchExpressionVariables = new HashMap<String, Object>();
switchExpressionVariables.put(EEFExpressionUtils.SELF, variableManager.getVariables().get(EEFExpressionUtils.SELF));
switchExpressionVariables.put(iterator, object);
diff --git a/plugins/org.eclipse.eef/model/eef.ecore b/plugins/org.eclipse.eef/model/eef.ecore
index 925acb916..37a83ce0b 100644
--- a/plugins/org.eclipse.eef/model/eef.ecore
+++ b/plugins/org.eclipse.eef/model/eef.ecore
@@ -515,10 +515,10 @@
<details key="documentation" value="The name of the variable which contain the current value of the iteration."/>
</eAnnotations>
</eStructuralFeatures>
- <eStructuralFeatures xsi:type="ecore:EAttribute" name="domainClassExpression"
- lowerBound="1" eType="ecore:EDataType ../../org.eclipse.emf.ecore/model/Ecore.ecore#//EString">
+ <eStructuralFeatures xsi:type="ecore:EAttribute" name="iterableExpression" lowerBound="1"
+ eType="ecore:EDataType ../../org.eclipse.emf.ecore/model/Ecore.ecore#//EString">
<eAnnotations source="http://www.eclipse.org/emf/2002/GenModel">
- <details key="documentation" value="Used to compute the mappings to create using the domain class of the current object."/>
+ <details key="documentation" value="Used to compute the mappings to create by iterating on the result of this expression."/>
</eAnnotations>
</eStructuralFeatures>
<eStructuralFeatures xsi:type="ecore:EReference" name="ifs" lowerBound="1" upperBound="-1"
diff --git a/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EefPackageImpl.java b/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EefPackageImpl.java
index de9cb7c45..28e58c2bc 100644
--- a/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EefPackageImpl.java
+++ b/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EefPackageImpl.java
@@ -1495,7 +1495,7 @@ public class EefPackageImpl extends EPackageImpl implements EefPackage {
* @generated
*/
@Override
- public EAttribute getEEFDynamicMappingFor_DomainClassExpression() {
+ public EAttribute getEEFDynamicMappingFor_IterableExpression() {
return (EAttribute) eefDynamicMappingForEClass.getEStructuralFeatures().get(1);
}
@@ -2498,7 +2498,7 @@ public class EefPackageImpl extends EPackageImpl implements EefPackage {
eefDynamicMappingForEClass = createEClass(EefPackage.EEF_DYNAMIC_MAPPING_FOR);
createEAttribute(eefDynamicMappingForEClass, EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERATOR);
- createEAttribute(eefDynamicMappingForEClass, EefPackage.EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION);
+ createEAttribute(eefDynamicMappingForEClass, EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION);
createEReference(eefDynamicMappingForEClass, EefPackage.EEF_DYNAMIC_MAPPING_FOR__IFS);
eefDynamicMappingIfEClass = createEClass(EefPackage.EEF_DYNAMIC_MAPPING_IF);
@@ -3088,9 +3088,9 @@ public class EefPackageImpl extends EPackageImpl implements EefPackage {
theEcorePackage.getEString(),
"iterator", null, 1, 1, EEFDynamicMappingFor.class, !EPackageImpl.IS_TRANSIENT, !EPackageImpl.IS_VOLATILE, EPackageImpl.IS_CHANGEABLE, !EPackageImpl.IS_UNSETTABLE, !EPackageImpl.IS_ID, EPackageImpl.IS_UNIQUE, !EPackageImpl.IS_DERIVED, EPackageImpl.IS_ORDERED); //$NON-NLS-1$
initEAttribute(
- getEEFDynamicMappingFor_DomainClassExpression(),
+ getEEFDynamicMappingFor_IterableExpression(),
theEcorePackage.getEString(),
- "domainClassExpression", null, 1, 1, EEFDynamicMappingFor.class, !EPackageImpl.IS_TRANSIENT, !EPackageImpl.IS_VOLATILE, EPackageImpl.IS_CHANGEABLE, !EPackageImpl.IS_UNSETTABLE, !EPackageImpl.IS_ID, EPackageImpl.IS_UNIQUE, !EPackageImpl.IS_DERIVED, EPackageImpl.IS_ORDERED); //$NON-NLS-1$
+ "iterableExpression", null, 1, 1, EEFDynamicMappingFor.class, !EPackageImpl.IS_TRANSIENT, !EPackageImpl.IS_VOLATILE, EPackageImpl.IS_CHANGEABLE, !EPackageImpl.IS_UNSETTABLE, !EPackageImpl.IS_ID, EPackageImpl.IS_UNIQUE, !EPackageImpl.IS_DERIVED, EPackageImpl.IS_ORDERED); //$NON-NLS-1$
initEReference(
getEEFDynamicMappingFor_Ifs(),
this.getEEFDynamicMappingIf(),

Back to the top
diff --git a/plugins/org.eclipse.eef.edit/src-gen/org/eclipse/eef/provider/EEFDynamicMappingForItemProvider.java b/plugins/org.eclipse.eef.edit/src-gen/org/eclipse/eef/provider/EEFDynamicMappingForItemProvider.java
index 7398db44b..9eae237bb 100644
--- a/plugins/org.eclipse.eef.edit/src-gen/org/eclipse/eef/provider/EEFDynamicMappingForItemProvider.java
+++ b/plugins/org.eclipse.eef.edit/src-gen/org/eclipse/eef/provider/EEFDynamicMappingForItemProvider.java
@@ -49,7 +49,7 @@ public class EEFDynamicMappingForItemProvider extends EEFControlDescriptionItemP
super.getPropertyDescriptors(object);
addIteratorPropertyDescriptor(object);
- addDomainClassExpressionPropertyDescriptor(object);
+ addIterableExpressionPropertyDescriptor(object);
}
return itemPropertyDescriptors;
}
@@ -67,20 +67,20 @@ public class EEFDynamicMappingForItemProvider extends EEFControlDescriptionItemP
}
/**
* This adds a property descriptor for the Domain Class Expression feature. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
* @generated
*/
- protected void addDomainClassExpressionPropertyDescriptor(Object object) {
+ protected void addIterableExpressionPropertyDescriptor(Object object) {
itemPropertyDescriptors
.add(createItemPropertyDescriptor(
((ComposeableAdapterFactory) adapterFactory).getRootAdapterFactory(),
getResourceLocator(),
- getString("_UI_EEFDynamicMappingFor_domainClassExpression_feature"), //$NON-NLS-1$
+ getString("_UI_EEFDynamicMappingFor_iterableExpression_feature"), //$NON-NLS-1$
getString(
- "_UI_PropertyDescriptor_description", "_UI_EEFDynamicMappingFor_domainClassExpression_feature", "_UI_EEFDynamicMappingFor_type"), //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
- EefPackage.Literals.EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION, true, false, false,
+ "_UI_PropertyDescriptor_description", "_UI_EEFDynamicMappingFor_iterableExpression_feature", "_UI_EEFDynamicMappingFor_type"), //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+ EefPackage.Literals.EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION, true, false, false,
ItemPropertyDescriptor.GENERIC_VALUE_IMAGE, null, null));
}
@@ -159,7 +159,7 @@ public class EEFDynamicMappingForItemProvider extends EEFControlDescriptionItemP
switch (notification.getFeatureID(EEFDynamicMappingFor.class)) {
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERATOR:
- case EefPackage.EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION:
+ case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION:
fireNotifyChanged(new ViewerNotification(notification, notification.getNotifier(), false, true));
return;
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__IFS:
@@ -67,20 +67,20 @@ public class EEFDynamicMappingForItemProvider extends EEFControlDescriptionItemP
}
/**
- * This adds a property descriptor for the Domain Class Expression feature. <!-- begin-user-doc --> <!--
- * end-user-doc -->
+ * This adds a property descriptor for the Iterable Expression feature. <!-- begin-user-doc --> <!-- end-user-doc
+ * -->
*
* @generated
diff --git a/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EEFDynamicMappingFor.java b/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EEFDynamicMappingFor.java
index 3308f4ce4..27cc45ad0 100644
--- a/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EEFDynamicMappingFor.java
+++ b/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EEFDynamicMappingFor.java
@@ -18,7 +18,7 @@ import org.eclipse.emf.common.util.EList;
* The following features are supported:
* <ul>
* <li>{@link org.eclipse.eef.EEFDynamicMappingFor#getIterator <em>Iterator</em>}</li>
- * <li>{@link org.eclipse.eef.EEFDynamicMappingFor#getDomainClassExpression <em>Domain Class Expression</em>}</li>
+ * <li>{@link org.eclipse.eef.EEFDynamicMappingFor#getIterableExpression <em>Iterable Expression</em>}</li>
* <li>{@link org.eclipse.eef.EEFDynamicMappingFor#getIfs <em>Ifs</em>}</li>
* </ul>
* </p>
@@ -53,28 +53,28 @@ public interface EEFDynamicMappingFor extends EEFControlDescription {
void setIterator(String value);
/**
* Returns the value of the '<em><b>Domain Class Expression</b></em>' attribute. <!-- begin-user-doc --> <!--
* end-user-doc --> <!-- begin-model-doc --> Used to compute the mappings to create using the domain class of the
* current object. <!-- end-model-doc -->
*
* @return the value of the '<em>Domain Class Expression</em>' attribute.
* @see #setDomainClassExpression(String)
* @see org.eclipse.eef.EefPackage#getEEFDynamicMappingFor_DomainClassExpression()
* @model required="true"
* @generated
*/
- String getDomainClassExpression();
+ String getIterableExpression();
/**
* Sets the value of the '{@link org.eclipse.eef.EEFDynamicMappingFor#getDomainClassExpression
* <em>Domain Class Expression</em>}' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @param value
* the new value of the '<em>Domain Class Expression</em>' attribute.
* @see #getDomainClassExpression()
* @generated
*/
- void setDomainClassExpression(String value);
+ void setIterableExpression(String value);
/**
* Returns the value of the '<em><b>Ifs</b></em>' containment reference list. The list contents are of type
@@ -53,28 +53,28 @@ public interface EEFDynamicMappingFor extends EEFControlDescription {
void setIterator(String value);
/**
- * Returns the value of the '<em><b>Domain Class Expression</b></em>' attribute. <!-- begin-user-doc --> <!--
- * end-user-doc --> <!-- begin-model-doc --> Used to compute the mappings to create using the domain class of the
- * current object. <!-- end-model-doc -->
+ * Returns the value of the '<em><b>Iterable Expression</b></em>' attribute. <!-- begin-user-doc --> <!--
+ * end-user-doc --> <!-- begin-model-doc --> Used to compute the mappings to create by iterating on the result of
+ * this expression. <!-- end-model-doc -->
*
@@ -53,28 +53,28 @@ public interface EEFDynamicMappingFor extends EEFControlDescription {
*
- * @return the value of the '<em>Domain Class Expression</em>' attribute.
- * @see #setDomainClassExpression(String)
- * @see org.eclipse.eef.EefPackage#getEEFDynamicMappingFor_DomainClassExpression()
+ * @return the value of the '<em>Iterable Expression</em>' attribute.
+ * @see #setIterableExpression(String)
+ * @see org.eclipse.eef.EefPackage#getEEFDynamicMappingFor_IterableExpression()
* @model required="true"
* @generated
@@ -53,28 +53,28 @@ public interface EEFDynamicMappingFor extends EEFControlDescription {
/**
- * Sets the value of the '{@link org.eclipse.eef.EEFDynamicMappingFor#getDomainClassExpression
- * <em>Domain Class Expression</em>}' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * Sets the value of the '{@link org.eclipse.eef.EEFDynamicMappingFor#getIterableExpression
+ * <em>Iterable Expression</em>}' attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @param value
@@ -53,28 +53,28 @@ public interface EEFDynamicMappingFor extends EEFControlDescription {
*
* @param value
- * the new value of the '<em>Domain Class Expression</em>' attribute.
- * @see #getDomainClassExpression()
+ * the new value of the '<em>Iterable Expression</em>' attribute.
+ * @see #getIterableExpression()
* @generated
*/
diff --git a/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EefPackage.java b/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EefPackage.java
index 3a0d6e35a..77867ac8d 100644
--- a/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EefPackage.java
+++ b/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/EefPackage.java
@@ -1524,13 +1524,13 @@ public interface EefPackage extends EPackage {
int EEF_DYNAMIC_MAPPING_FOR__ITERATOR = EefPackage.EEF_CONTROL_DESCRIPTION_FEATURE_COUNT + 0;
/**
* The feature id for the '<em><b>Domain Class Expression</b></em>' attribute. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
* @generated
* @ordered
*/
- int EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION = EefPackage.EEF_CONTROL_DESCRIPTION_FEATURE_COUNT + 1;
+ int EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION = EefPackage.EEF_CONTROL_DESCRIPTION_FEATURE_COUNT + 1;
/**
* The feature id for the '<em><b>Ifs</b></em>' containment reference list. <!-- begin-user-doc --> <!--
@@ -4238,15 +4238,15 @@ public interface EefPackage extends EPackage {
EAttribute getEEFDynamicMappingFor_Iterator();
/**
* Returns the meta object for the attribute '{@link org.eclipse.eef.EEFDynamicMappingFor#getDomainClassExpression
* <em>Domain Class Expression</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @return the meta object for the attribute '<em>Domain Class Expression</em>'.
* @see org.eclipse.eef.EEFDynamicMappingFor#getDomainClassExpression()
* @see #getEEFDynamicMappingFor()
* @generated
*/
- EAttribute getEEFDynamicMappingFor_DomainClassExpression();
+ EAttribute getEEFDynamicMappingFor_IterableExpression();
/**
* Returns the meta object for the containment reference list '{@link org.eclipse.eef.EEFDynamicMappingFor#getIfs
@@ -6015,12 +6015,12 @@ public interface EefPackage extends EPackage {
EAttribute EEF_DYNAMIC_MAPPING_FOR__ITERATOR = EefPackage.eINSTANCE.getEEFDynamicMappingFor_Iterator();
/**
* The meta object literal for the '<em><b>Domain Class Expression</b></em>' attribute feature. <!--
* begin-user-doc --> <!-- end-user-doc -->
*
* @generated
*/
- EAttribute EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION = EefPackage.eINSTANCE.getEEFDynamicMappingFor_DomainClassExpression();
+ EAttribute EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION = EefPackage.eINSTANCE.getEEFDynamicMappingFor_IterableExpression();
/**
* The meta object literal for the '<em><b>Ifs</b></em>' containment reference list feature. <!-- begin-user-doc
@@ -1524,13 +1524,13 @@ public interface EefPackage extends EPackage {
int EEF_DYNAMIC_MAPPING_FOR__ITERATOR = EefPackage.EEF_CONTROL_DESCRIPTION_FEATURE_COUNT + 0;
/**
- * The feature id for the '<em><b>Domain Class Expression</b></em>' attribute. <!-- begin-user-doc --> <!--
- * end-user-doc -->
- *
+ * The feature id for the '<em><b>Iterable Expression</b></em>' attribute. <!-- begin-user-doc --> <!-- end-user-doc
+ * -->
+ *
* @generated
* @ordered
@@ -4238,15 +4238,15 @@ public interface EefPackage extends EPackage {
EAttribute getEEFDynamicMappingFor_Iterator();
/**
- * Returns the meta object for the attribute '{@link org.eclipse.eef.EEFDynamicMappingFor#getDomainClassExpression
- * <em>Domain Class Expression</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
- *
- * @return the meta object for the attribute '<em>Domain Class Expression</em>'.
- * @see org.eclipse.eef.EEFDynamicMappingFor#getDomainClassExpression()
+ * Returns the meta object for the attribute '{@link org.eclipse.eef.EEFDynamicMappingFor#getIterableExpression
+ * <em>Iterable Expression</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
+ *
+ * @return the meta object for the attribute '<em>Iterable Expression</em>'.
+ * @see org.eclipse.eef.EEFDynamicMappingFor#getIterableExpression()
* @see #getEEFDynamicMappingFor()
* @generated
@@ -6015,12 +6015,12 @@ public interface EefPackage extends EPackage {
EAttribute EEF_DYNAMIC_MAPPING_FOR__ITERATOR = EefPackage.eINSTANCE.getEEFDynamicMappingFor_Iterator();
/**
- * The meta object literal for the '<em><b>Domain Class Expression</b></em>' attribute feature. <!--
- * begin-user-doc --> <!-- end-user-doc -->
+ * The meta object literal for the '<em><b>Iterable Expression</b></em>' attribute feature. <!-- begin-user-doc
+ * --> <!-- end-user-doc -->
*
* @generated
diff --git a/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EEFDynamicMappingForImpl.java b/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EEFDynamicMappingForImpl.java
index 5e2c09d69..2854ab25d 100644
--- a/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EEFDynamicMappingForImpl.java
+++ b/plugins/org.eclipse.eef/src-gen/org/eclipse/eef/impl/EEFDynamicMappingForImpl.java
@@ -29,7 +29,7 @@ import org.eclipse.emf.ecore.util.InternalEList;
* The following features are implemented:
* <ul>
* <li>{@link org.eclipse.eef.impl.EEFDynamicMappingForImpl#getIterator <em>Iterator</em>}</li>
- * <li>{@link org.eclipse.eef.impl.EEFDynamicMappingForImpl#getDomainClassExpression <em>Domain Class Expression</em>}</li>
+ * <li>{@link org.eclipse.eef.impl.EEFDynamicMappingForImpl#getIterableExpression <em>Iterable Expression</em>}</li>
* <li>{@link org.eclipse.eef.impl.EEFDynamicMappingForImpl#getIfs <em>Ifs</em>}</li>
* </ul>
* </p>
@@ -58,24 +58,24 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
protected String iterator = EEFDynamicMappingForImpl.ITERATOR_EDEFAULT;
/**
* The default value of the '{@link #getDomainClassExpression() <em>Domain Class Expression</em>}' attribute. <!--
* begin-user-doc --> <!-- end-user-doc -->
*
- * @see #getDomainClassExpression()
+ * @see #getIterableExpression()
* @generated
* @ordered
*/
- protected static final String DOMAIN_CLASS_EXPRESSION_EDEFAULT = null;
+ protected static final String ITERABLE_EXPRESSION_EDEFAULT = null;
/**
* The cached value of the '{@link #getDomainClassExpression() <em>Domain Class Expression</em>}' attribute. <!--
* begin-user-doc --> <!-- end-user-doc -->
*
- * @see #getDomainClassExpression()
+ * @see #getIterableExpression()
* @generated
* @ordered
*/
- protected String domainClassExpression = EEFDynamicMappingForImpl.DOMAIN_CLASS_EXPRESSION_EDEFAULT;
+ protected String iterableExpression = EEFDynamicMappingForImpl.ITERABLE_EXPRESSION_EDEFAULT;
/**
* The cached value of the '{@link #getIfs() <em>Ifs</em>}' containment reference list. <!-- begin-user-doc --> <!--
@@ -136,8 +136,8 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
* @generated
*/
@Override
- public String getDomainClassExpression() {
- return domainClassExpression;
+ public String getIterableExpression() {
+ return iterableExpression;
}
/**
@@ -146,12 +146,12 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
* @generated
*/
@Override
- public void setDomainClassExpression(String newDomainClassExpression) {
- String oldDomainClassExpression = domainClassExpression;
- domainClassExpression = newDomainClassExpression;
+ public void setIterableExpression(String newIterableExpression) {
+ String oldIterableExpression = iterableExpression;
+ iterableExpression = newIterableExpression;
if (eNotificationRequired()) {
- eNotify(new ENotificationImpl(this, Notification.SET, EefPackage.EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION,
- oldDomainClassExpression, domainClassExpression));
+ eNotify(new ENotificationImpl(this, Notification.SET, EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION, oldIterableExpression,
+ iterableExpression));
}
}
@@ -192,8 +192,8 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
switch (featureID) {
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERATOR:
return getIterator();
- case EefPackage.EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION:
- return getDomainClassExpression();
+ case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION:
+ return getIterableExpression();
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__IFS:
return getIfs();
}
@@ -212,8 +212,8 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERATOR:
setIterator((String) newValue);
return;
- case EefPackage.EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION:
- setDomainClassExpression((String) newValue);
+ case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION:
+ setIterableExpression((String) newValue);
return;
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__IFS:
getIfs().clear();
@@ -234,8 +234,8 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERATOR:
setIterator(EEFDynamicMappingForImpl.ITERATOR_EDEFAULT);
return;
- case EefPackage.EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION:
- setDomainClassExpression(EEFDynamicMappingForImpl.DOMAIN_CLASS_EXPRESSION_EDEFAULT);
+ case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION:
+ setIterableExpression(EEFDynamicMappingForImpl.ITERABLE_EXPRESSION_EDEFAULT);
return;
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__IFS:
getIfs().clear();
@@ -255,9 +255,9 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERATOR:
return EEFDynamicMappingForImpl.ITERATOR_EDEFAULT == null ? iterator != null : !EEFDynamicMappingForImpl.ITERATOR_EDEFAULT
.equals(iterator);
- case EefPackage.EEF_DYNAMIC_MAPPING_FOR__DOMAIN_CLASS_EXPRESSION:
- return EEFDynamicMappingForImpl.DOMAIN_CLASS_EXPRESSION_EDEFAULT == null ? domainClassExpression != null
- : !EEFDynamicMappingForImpl.DOMAIN_CLASS_EXPRESSION_EDEFAULT.equals(domainClassExpression);
+ case EefPackage.EEF_DYNAMIC_MAPPING_FOR__ITERABLE_EXPRESSION:
+ return EEFDynamicMappingForImpl.ITERABLE_EXPRESSION_EDEFAULT == null ? iterableExpression != null
+ : !EEFDynamicMappingForImpl.ITERABLE_EXPRESSION_EDEFAULT.equals(iterableExpression);
case EefPackage.EEF_DYNAMIC_MAPPING_FOR__IFS:
return ifs != null && !ifs.isEmpty();
}
@@ -278,8 +278,8 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
StringBuffer result = new StringBuffer(super.toString());
result.append(" (iterator: "); //$NON-NLS-1$
result.append(iterator);
- result.append(", domainClassExpression: "); //$NON-NLS-1$
- result.append(domainClassExpression);
+ result.append(", iterableExpression: "); //$NON-NLS-1$
+ result.append(iterableExpression);
result.append(')');
return result.toString();
}
@@ -58,24 +58,24 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
protected String iterator = EEFDynamicMappingForImpl.ITERATOR_EDEFAULT;
/**
- * The default value of the '{@link #getDomainClassExpression() <em>Domain Class Expression</em>}' attribute. <!--
+ * The default value of the '{@link #getIterableExpression() <em>Iterable Expression</em>}' attribute. <!--
* begin-user-doc --> <!-- end-user-doc -->
*
@@ -58,24 +58,24 @@ public class EEFDynamicMappingForImpl extends EEFControlDescriptionImpl implemen
/**
- * The cached value of the '{@link #getDomainClassExpression() <em>Domain Class Expression</em>}' attribute. <!--
+ * The cached value of the '{@link #getIterableExpression() <em>Iterable Expression</em>}' attribute. <!--
* begin-user-doc --> <!-- end-user-doc -->
*